@@ -289,7 +289,7 @@ def update_map_of_PDBs_with_all_residue_pairs(
     """
     ...
     """
-    updated_set_of_PDBs_with_all_residue_pairs = map_of_PDBs_with_all_residue_pairs.keys() & new_residue_pair_data.keys() # & = set intersection 
+    updated_set_of_PDBs_with_all_residue_pairs = map_of_PDBs_with_all_residue_pairs.keys() & new_residue_pair_data.keys() # & = set intersection
     
     for PDB_ID in list(map_of_PDBs_with_all_residue_pairs.keys()):
         if PDB_ID not in updated_set_of_PDBs_with_all_residue_pairs:
@@ -424,13 +424,14 @@ def solve_motif_MST(
                 PDBs_that_contain_the_residue_pair
             )
 
-    # Non-parallel version of filter_out_PDBs_with_unconnected_residue_pairs
-    #print(f'Filtering {len(map_of_PDBs_with_all_residue_pairs)} target motifs.')
+    # Non-parallel version of filter_out_PDBs_with_unconnected_residue_pairs. Using while loop + popitem()
+    # instead of a for loop because it reduces the RAM usage.
     add_resname_as_node_attribute(motif_MST) # Needed for subgraph monomorphism, see run_subgraph_monomorphism().
     filtered_PDBs_with_all_residue_pairs: Dict[str, List[nx.Graph]] =  {}
-    for PDB_ID, pairs_of_residues in map_of_PDBs_with_all_residue_pairs.items():
+    while map_of_PDBs_with_all_residue_pairs:
+        PDB_ID, pairs_of_residues = map_of_PDBs_with_all_residue_pairs.popitem()
         monomorphism_checked_motifs = run_subgraph_monomorphism(motif_MST, pairs_of_residues)
-
+        
         if not monomorphism_checked_motifs: # These are the false positive PDBs, i.e PDBs that have all the residue pairs but where the monomorphism check doesn't find any similar motif as a result of unconnected pairs of residues 
             continue
 
